import 'package:google_maps_flutter/google_maps_flutter.dart';
import 'package:polyline_builder/src/services/api_mapbox/polyline_list_service/models/polyline_list_response_model.dart';
import 'package:polyline_builder/src/services/api_mapbox/polyline_list_service/polyline_list_service.dart';
import 'package:list_chunker/list_chunker.dart';

import 'models/polilyne_model.dart';

class PolylineProvider {
  static final PolylineListService _polylineService =
      PolylineListService.create();

  static Future<List<PolylineModel>> getPolylines(
      List<LatLng> locations) async {
    List<Future> futures = [];

    List waypoinst = locations.chunk(25); // 25 is max allowed by mapbox api

    // Ensure last one has at least 2 locations
    if (waypoinst.last.length == 1)
      waypoinst.last.insert(0, waypoinst[waypoinst.length - 2].last);

    for (var i = 0; i < waypoinst.length; i++) {
      futures.add(_polylineService.getPolylines(
          PolylineListService.buildCoordinatesFromLatLng(waypoinst[i]),
          'es',
          false,
          'polyline6',
          true));
    }

    final List responses = await Future.wait(futures);

    List<PolylineModel> polylineList = List<PolylineModel>();

    responses?.forEach((e) {
      final response = e.body as PolylineListResponseModel;
      double distance = 0;
      double duration = 0;

      final r = response.routes.first;
      distance += r.distance;
      duration += r.duration;

      polylineList.add(PolylineModel(
        polilyne: response.toGoogleMapPolylineSet(),
        distance: distance,
        duration: duration,
      ));
    });

    return polylineList;
  }
}
